#
# spec file for package tkdiff
#
# Copyright (c) 2021 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global longver 5-2-1
%global shortver %(echo %{longver}|sed 's|-|.|g')
Name:           tkdiff
Version:        %{shortver}
Release:        bp154.1.18
Summary:        2 and 3-way diff/merge tool
License:        GPL-2.0-or-later
Group:          Productivity/Text/Utilities
URL:            http://tkdiff.sourceforge.net/
Source0:        http://prdownloads.sourceforge.net/tkdiff/tkdiff-%{longver}.zip
Source1:        README.SUSE
BuildRequires:  unzip
Requires:       diffutils
Requires:       tcl
Requires:       tk
BuildArch:      noarch

%description
TkDiff is a graphical 2 and 3-way diff/merge tool.

%prep
%setup -q -n tkdiff-%{longver}
cp %{SOURCE1} .

%build

%install
install -Dpm 0755 tkdiff \
  %{buildroot}%{_bindir}/tkdiff

%files
%doc README.SUSE
%{_bindir}/tkdiff

%changelog
* Sun Oct 17 2021 hsk17@mail.de
- for release info see also https://sourceforge.net/p/tkdiff/news/
- Update to 5.2.1
  * Now provides an alternate means of displaying the list of file
    pairs (in a free standing dialog) when the number of files exceeds
    a user adjustable (1-25) maximum for using a simple menu choice.
  * Repaired what filenames are returned by a 'recursive' Diff search
    when the "-q" option is removed. Will now suppress binary files as
    originally intended (fault was caused by Tcl itself - not TkDiff).
  * Fixed initial display of toolbar buttons at startup. Was displaying
    BOTH text and icon versions (overlaid) until after a preference
    "Apply" had occurred.
- Update to 5.2
  * Permits recursive scanning of entire directory TREEs for candidate
    files. Uses Diff itself to perform the search by passing the needed
    options, which then become a new preference setting (to allow for
    alternative Diff engine usage)
  * Now shades the BOUNDARY LINE during "Split"-push manipulations:
    provides clearer feedback; edge is now perceived to exist immediately
    BETWEEN the shaded line and the line directly above it
  * Reduced 'interactive startup' reliance on a message console and now
    promotes a "retry" paradigm, rather than aborting, by presenting the
    interactive command dialog after issuing MOST startup failure messages
  * Fixed broken "Find Nearest Diff" (via the popup menu) to now use the
    user chosen popup LOCATION as the point for measuring "Nearest"
  * Repaired derivation of the INITIAL temp-dir path preference for NEW
    WINDOWS users that was broken by previous release.
  * Resolved minor clipping issue in toolbar combobox (re: fonts)
  * Avoid Diff crash caused by specifying MULTIPLE unique "ignore blanks"
    preference options
  * Avoid crash from malformed filename utilizing tilde-expansion to a
    non-existant user
  * Repaired missing Key Accelerator+Tip for File->Recompute menu item
  * Toolbar buttons now reset fully when a valid Diff execution happens
    to yeild ZERO results
  * Visible Focus-tabbing restored to dir/file browser buttons in the
    NewDiff dialog to facilitate keyboard navigation
- Update to 5.1
  * Complete overhaul of keyboard bindings provides user selection
    adds a 4th preferences editing tab for personalization of same
  * Expanded Bookmark facility including scrollability of items when
    toolbar capacity is exceeded. Bookmarks may be individually
    annotated and form the basis of a new item specific report format
  * Additional report format and ability to view complexity statistics
    without needing to generate an actual report
  * Internal reengineering of Read-Only text display implementation
    has restored keyboard-centric operation throughout the tool
  * Network latency support is now restored to the MacOS platform
  * General fault-tolerance throughout the tool has been increased
    with greater use of onscreen messaging instead of aborting.
  * Monochrome support has been discontinued (most features unusable).
  * Specific Ticket resolutions addressed:
  - (73) Crash caused from inadvertent mispelling of command
  - (74) Crash from scrolling prior to first hunk w/autoselect = on.
    Further, autoselect now operates passively when actively
    scrolling (will no longer trigger autocenter if active)
  - (75) a syntactic repair to prevent a Crash when chosing either
    of the L/R or R/L merge choices
  * Other anomalies resolved:
  - Repaired a data-dependant corner case which could either Crash or
    result in incomplete highlighting of 3way Diff ancestral markers
  - Resizing the main window smaller now operates properly; had been
    only allowing approximately 40%% reduction.
  - Minor fix (toolwide) prevents wrong subwindows from squeezing shut
    prematurely during resizing to a smaller size.
  - Auxilliary windows (dialogs) now generally retain their prior
    positions when re-appearing after the user has moved them.
  - Tooltip windows on MacOS will never again display UNDER others.
  * Specific internal infrastructure modifications have produced a
    considerable level of uniformity and reliability throughout.
  * Special case workaround (re: multiple display monitors)
    Operations involving screen-edge clipping avoidance are presently
    flawed under TK. Until a better solution can be found, edge
    avoidance for windows appearing on secondary displays will be to
    their main window and not the screen edge. This generally affects
    Tooltips and combobox dropdown lists.
  * As always, builtin Help is updated to cover ALL change aspects
    it is recommended to read at least the process for bind editting
- Update to 5.0
  * New-Diff Dialog can now request Conflict file comparisons
  - It also permits choosing a preferred SCM system from among those
    detected, and is now ALWAYS the defaulted first operation when
    NO command line arguments are given - UNLESS one specific user
    preference has PREVIOUSLY been set which requests that the SCM
    inquire for currently uncommitted changes and supply those as
    parameters instead (not all SCMs can do this). For those that do,
    that search request may ALSO be accessed for the current session
    via the Dialog, even when such preference has been set to Off.
  * CVS (like Git and Subversion) is now capable of automatic inquiry
  * ALL SCMs capable of inquiry also pass CONFLICTED files when found
  * URLs (Svn style) are now accepted as FileSpecs in Dialog or Cmd use.
  - Including both versioned and defaulted styles, and as an Ancestor.
  * Multiple SCM involvement is now possible.
  * Merging when using an Ancestor file (ie. a 3-way diff) now provides
    Ancestral markers for deletion activities, similar to those
    already provided for additions, which also participate in both
    automatic merge selection choices AND collision detection, all in
    support of assuring that COMPLETE changes from both files being
    merged are accounted for.
  * Upgraded Conflictfile parsing to accept diff3-style file content
    providing the ability to treat it as in a 3-way Diff mode.
  * Interactive diff-region suppression (ie. ignoring) is now possible
  * Eliminated a TK-update race condition that was randomly responsible
    for odd crashes and potentially inconsistent screen updates
  * Minor feature enhancements:
  - Window manager is now provided a graphic to represent TkDiff
  - Displayed file NAMES now try to be shorter by truncating the CWD
  - Failed (or inconsistent) Diff executions are no longer fatal
  - 3-way Diffs using a non-unique Ancestor now simply drops 3-way mode
  * Small repairs involving: line numbering; Mac tooltip rendering;
    several hilighting anomolies involving suppressed Diff regions;
    and missing bindings when positioned over various Text-adjacent
    Info windows involving scroll operations. Lastly, filenames with
    sensitive characters (Dollar, square-Bracket) in their names
    will no longer crash, and the default setting for Filebrowser
    view-content filters is now specified properly.
  * And the builtin Help is updated to cover aspects of ALL the changes
- Update README.SUSE accordingly
* Fri Oct  5 2018 Martin Pluskal <mpluskal@suse.com>
- Use variables for version handling
- Update dependencies
* Thu Oct  4 2018 Michał Rostecki <mrostecki@suse.de>
- Update to 4.3.5
  * New Diff Dialog now allows browsing for files OR directories
  * Tool arguments now permit cross-branch SCM comparison
    specification
  * Ability to view Ancestorfile also denotes 3way mode is active
  * 3-way collisions now findable via toolbar dropdown list
    highlights
  * Textwin labels now tooltip the name & modtime of any NON-temp
    file
  * Builtin editor now provides Line numbers
  * Recent new color preference settings repaired to "apply"
    correctly
  * Crash fixed when 3-way diff was active and Lnums & Chgbars are
    OFF
  * Pre-startup latency msg feature now OFF (MacOS X only) stops
    Crash
  * Repaired Lnums,etc. to use CDR preference settings when
    appropriate
* Mon Nov 13 2017 mpluskal@suse.com
- Run spec-cleaner
* Mon Nov 13 2017 dimstar@opensuse.org
- Rename README.SuSE to README.SUSE, adhering to the correct
  spelling.
* Mon Nov 28 2011 pascal.bleser@opensuse.org
- update to 4.2:
  * works with Subversion 1.7
  * make opening file dialog know where it started from, and start in the same
    directory as the first file when looking for the second one
  * you can now specify a preference for filetypes for the file open/save
    dialogs
  * detect PVCS by environment variable (patch 1839361 by nafmo)
  * update BitKeeper support (patch 3053551 by wscott)
  * mercurial support (patch 1867700 by damonmc)
  * rudimentary Git support (patch 1836293 by cecilh3)
  * add help menu items to report versions of wish and diff
  * gave it a debug (-d) option
* Thu Jul 21 2011 rcoe@wi.rr.com
- patch to add git support from sf.net#1836293
* Tue Nov 27 2007 lmichnovic@suse.cz
- update to version 4.1.4
  * Ignore -u option from svn for usage "svn diff --diff-cmd=tkdiff"
  * Perforce support for P4CONFIG environment variable
  * Remove an old font work-around for Mac, but add a new one for tk8.5
  on Windows
  * Fix duplicate keyboard accelerator for Preferences
* Fri Aug 11 2006 lmichnovic@suse.cz
- changed bindir to /usr/bin
* Tue Jun 20 2006 lmichnovic@suse.cz
- update to verson 4.1.3
  * Fixed incompatibility with older versions of Tcl/Tk
    ("-state disabled").
  * Applied Warren Jones' subversion patch, which prevents the svn
    error that occurs when you omit a revision number.
  * Can now do "tkdiff OLD-URL[@OLDREV] NEW-URL[@NEWREV]" in svn.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  2 2006 lmichnovic@suse.cz
- update to version 4.1.1 which includes security patch for temp files
  (CVE-2005-4434) [#141076]
- updated copyright in README.SuSE file
* Thu Sep 29 2005 dmueller@suse.de
- add norootforbuild
* Mon Nov 15 2004 ltinkl@suse.cz
- updated to 4.0.2
* Sun Oct 10 2004 schwab@suse.de
- Fix requires.
* Fri Sep  6 2002 pmladek@suse.cz
- fixed usage of -pad
* Fri Aug 17 2001 pmladek@suse.cz
- updated to version 3.09
- README.SuSE moved to sources
* Wed Mar 28 2001 nadvornik@suse.cz
- update to 3.08
* Thu Nov 23 2000 ro@suse.de
- fixed requires
* Thu Oct 12 2000 nadvornik@suse.cz
- new package
